@@ -101,7 +101,7 @@ def get(fname=OUTFILE):
 	station_closures = ""
 	interchange_closures = ""
 
-	if not (old(fname) or outdated(fname)):
+	if (old(fname) or outdated(fname)):
 		try:
 			print "Fetching data from TfL website..."
 			f = urllib.urlopen(URL, None)
@@ -159,7 +159,7 @@ def get(fname=OUTFILE):
 	if delays == "":
 		delays = ";"
 
-	if (not path.exists(fname)) or outdated(fname):
+	if (not path.exists(fname)) or outdated(fname) or old(fname):
 		try:
 			print "Writing file..."
 			f = open(fname, 'w')
