@@ -23,7 +23,7 @@ DATA_FILE = BASE_DIR + 'Tubes.dat'
 CLOSURES_FILE = BASE_DIR + 'Closures.txt'
 CONFIG_FILE = 'Config.txt'
 
-MAP_IMAGE = os.path.dirname(argv[0]) + "/tfl_map.gif"
+MAP_IMAGE = BASE_DIR + "Map.gif"
 MAP_SCALE = 2
 MAP_BUFFER = 10
 
